## ---------------------------
##
## Script name: 01_load_transform_and_save.R
##
## Purpose of script: Load 2021 WHAP seedhead data, transform, and save as csv
##
## Author: Cora B. Davies, FWS R8 Refuges I&M
##
## Email: cora_davies@fws.gov
##
## Date Created: 2024-05-17
##
## ---------------------------
##
## Notes:
##
## ---------------------------

# Setup -------------------------------
options(readr.show_col_types = FALSE)

# Initialize here::here()
try(here::i_am("src/01_load_transform_and_save.R"))

# Load libraries
library(tidyverse)
library(magrittr)
library(httr2)
library(here)

# Set up our standard project organization folders
code_dir <- here("src")
data_dir <- here("data")
results_dir <- here("results")

# Make sure these folders exist - not all must exist before getting started
if (!dir.exists(code_dir)) cli_abort("Script folder {code_dir} is missing")
if (!dir.exists(data_dir)) cli_abort("Data folder {data_dir} is missing")
if (!dir.exists(results_dir)) dir.create(results_dir)

# Compile data -------------------------------

# Read in data 
raw_data_xlsx <- here(data_dir, "whap_seedmodeldata_2021.xlsx")

# Dimensions data
dimensions <- readxl::read_excel(
  raw_data_xlsx,
  sheet = "dimensions"
)

# Weights data
weights <- readxl::read_excel(
  raw_data_xlsx,
  sheet = "weights"
)

# Merge data by bag_id
seedhead_data <- left_join(
  dimensions,
  weights, 
  by = join_by(bag_id))

# Save data -------------------------------

write_csv(seedhead_data, here(results_dir, "whap_seedmodeldata_2021.csv"))